@@ -95,12 +95,25 @@
 #' 
 #' @examples 
 #' \dontrun{
-#' data(Gravity)
+#' data(Gravity_no_zeros)
 #' 
-#' DDM(y="flow", dist="distw", x=c("rta"), vce_robust=TRUE, data=Gravity)
+#' DDM(y="flow", dist="distw", x=c("rta"), 
+#' vce_robust=TRUE, data=Gravity_no_zeros)
 #' 
 #' DDM(y="flow", dist="distw", x=c("rta", "comcur", "contig"), 
-#' vce_robust=FALSE, data=Gravity)
+#' vce_robust=TRUE, data=Gravity_no_zeros)
+#' }
+#' 
+#' \dontshow{
+#' # examples for CRAN checks:
+#' # executable in < 5 sec together with the examples above
+#' # not shown to users
+#' 
+#' data(Gravity_no_zeros)
+#' # choose exemplarily 10 biggest countries for check data
+#' countries_chosen <- names(sort(table(Gravity_no_zeros$iso_o), decreasing = TRUE)[1:10])
+#' grav_small <- Gravity_no_zeros[Gravity_no_zeros$iso_o %in% countries_chosen,]
+#' DDM(y="flow", dist="distw", x=c("rta"), vce_robust=TRUE, data=grav_small)
 #' }
 #' 
 #' @return
@@ -110,94 +123,85 @@
 #' @seealso \code{\link[stats]{lm}}, \code{\link[lmtest]{coeftest}}, 
 #' \code{\link[sandwich]{vcovHC}}
 #' 
-#' 
 #' @export 
 #' 
 DDM <- function(y, dist, x, vce_robust=TRUE, data, ...){
-  if(!is.data.frame(data))stop("'data' must be a 'data.frame'")
-  if((vce_robust %in% c(TRUE, FALSE)) == FALSE){
-    stop("'vce_robust' has to be either 'TRUE' or 'FALSE'")}
+  
+  if(!is.data.frame(data))                                                stop("'data' must be a 'data.frame'")
+  if((vce_robust %in% c(TRUE, FALSE)) == FALSE)                           stop("'vce_robust' has to be either 'TRUE' or 'FALSE'")
   if(!is.character(y)     | !y%in%colnames(data)     | length(y)!=1)      stop("'y' must be a character of length 1 and a colname of 'data'")
   if(!is.character(dist)  | !dist%in%colnames(data)  | length(dist)!=1)   stop("'dist' must be a character of length 1 and a colname of 'data'")
-  if(!is.character(x)     | !all(x%in%colnames(data))) stop("'x' must be a character vector and all x's have to be colnames of 'data'")  
-  
+  if(!is.character(x)     | !all(x%in%colnames(data)))                    stop("'x' must be a character vector and all x's have to be colnames of 'data'")  
+
   # Transforming data, logging distances ---------------------------------------
   
-  d <- data
-  d$dist_log <- (log(d[dist][,1]))
-  d$count <- 1:length(d$iso_o)
+  d               <- data
+  d$dist_log      <- (log(d[dist][,1]))
+  d$count         <- 1:length(d$iso_o)
   
   # Transforming data, logging flows -------------------------------------------
   
-  d$y_log <- log(d[y][,1])
+  d$y_log         <- log(d[y][,1])
   
   # Substracting the means -----------------------------------------------------
   
-  d$y_log_dd <- rep(NA, times = length(d$dist_log))
-  d$dist_log_dd <- rep(NA, times = length(d$dist_log))
+  d$y_log_dd      <- rep(NA, times = length(d$dist_log))
+  d$dist_log_dd   <- rep(NA, times = length(d$dist_log))
   
-  mean.y_log.1 <- tapply(d$y_log, d$iso_o, mean)
-  mean.y_log.2 <- tapply(d$y_log, d$iso_d, mean)  
+  mean.y_log.1    <- tapply(d$y_log, d$iso_o, mean)
+  mean.y_log.2    <- tapply(d$y_log, d$iso_d, mean)  
   
   mean.dist_log.1 <- tapply(d$dist_log, d$iso_o, mean)
   mean.dist_log.2 <- tapply(d$dist_log, d$iso_d, mean)
 
-  d$y_log_dd <- d$y_log
-  d$dist_log_dd <- d$dist_log
+  d$y_log_dd      <- d$y_log
+  d$dist_log_dd   <- d$dist_log
   
   for(i in unique(d$iso_o)){
-    d[d$iso_o == i,]$y_log_dd <- d[d$iso_o == i,]$y_log_dd - mean.y_log.1[i]
-    d[d$iso_o == i,]$dist_log_dd <- 
-      d[d$iso_o == i,]$dist_log_dd - mean.dist_log.1[i]
+    d[d$iso_o == i,]$y_log_dd    <- d[d$iso_o == i,]$y_log_dd - mean.y_log.1[i]
+    d[d$iso_o == i,]$dist_log_dd <- d[d$iso_o == i,]$dist_log_dd - mean.dist_log.1[i]
   }
   
   for(i in unique(d$iso_d)){
-    d[d$iso_d == i,]$y_log_dd <- d[d$iso_d == i,]$y_log_dd - mean.y_log.2[i]
-    d[d$iso_d == i,]$dist_log_dd <- 
-      d[d$iso_d == i,]$dist_log_dd - mean.dist_log.2[i]
+    d[d$iso_d == i,]$y_log_dd    <- d[d$iso_d == i,]$y_log_dd - mean.y_log.2[i]
+    d[d$iso_d == i,]$dist_log_dd <- d[d$iso_d == i,]$dist_log_dd - mean.dist_log.2[i]
   }
   
-  d$y_log_dd <- d$y_log_dd + mean(d$y_log)
+  d$y_log_dd    <- d$y_log_dd + mean(d$y_log)
   d$dist_log_dd <-  d$dist_log_dd + mean(d$dist_log)
   
   # Substracting the means for the other independent variables -----------------
   
-  ind.var.dd <- list(length=length(x))
+  ind.var.dd     <- list(length=length(x))
   mean.ind.var.1 <- list(legth=length(x))
   mean.ind.var.2 <- list(legth=length(x))
   
   for(j in 1:length(x)){
-    ind.var.dd[[j]] <- d[x[j]][,1]
+    ind.var.dd[[j]]     <- d[x[j]][,1]
     mean.ind.var.1[[j]] <- tapply(d[x[j]][,1], d$iso_o, mean)
     mean.ind.var.2[[j]] <- tapply(d[x[j]][,1], d$iso_d, mean)
   }
   
-  w <- letters[1:length(x)]
+  w   <- letters[1:length(x)]
   
   d_2 <- d
   for(j in 1:length(x)){
     d_2[w[j]] <- ind.var.dd[[j]]
   }
-  
-  
-  ##klappt bis hier
-  
+
   d_3 <- d_2
   
   for(j in 1:length(x)){
     
     for(i in unique(d_2$iso_o)){
-      d_2[d_2$iso_o == i,][w[j]] <- 
-        d_2[d_2$iso_o == i,][w[j]] - mean.ind.var.1[[j]][i]
+      d_2[d_2$iso_o == i,][w[j]] <- d_2[d_2$iso_o == i,][w[j]] - mean.ind.var.1[[j]][i]
     }
     
     for(i in unique(d_2$iso_d)){
-      d_2[d_2$iso_d == i,][w[j]] <- 
-        d_2[d_2$iso_d == i,][w[j]] - mean.ind.var.2[[j]][i]
+      d_2[d_2$iso_d == i,][w[j]] <- d_2[d_2$iso_d == i,][w[j]] - mean.ind.var.2[[j]][i]
     }
     
     d_2[w[j]] <- d_2[w[j]] + mean(d_2[x[j]][,1])
-    
     d_3[x[j]] <- d_2[w[j]]
   }
   
@@ -207,29 +211,27 @@ DDM <- function(y, dist, x, vce_robust=TRUE, data, ...){
   
   # new row in dataset for independent _dd variable
   for(j in x){
-    l <- which(x == j)
-    dd <- x_dd[l]
+    l       <- which(x == j)
+    dd      <- x_dd[l]
     d_3[dd] <- NA
     d_3[dd] <- d_3[x[l]]
   }
   
-  vars <- paste(c("dist_log_dd", x_dd), collapse=" + ")
-  form <- paste("y_log_dd", "~", vars, "- 1")
-  form2 <- stats::as.formula(form)
+  vars      <- paste(c("dist_log_dd", x_dd), collapse=" + ")
+  form      <- paste("y_log_dd", "~", vars, "- 1")
+  form2     <- stats::as.formula(form)
   
   model.DDM <- stats::lm(form2, data = d_3)   
 
   # Return ---------------------------------------------------------------------
   
   if(vce_robust == TRUE){
-    return.object.1 <- .robustsummary.lm(model.DDM, robust=TRUE)
-    return.object.1$call <- form2
+    return.object.1         <- .robustsummary.lm(model.DDM, robust=TRUE)
+    return.object.1$call    <- form2
     return(return.object.1)}
   
   if(vce_robust == FALSE){
-    return.object.1 <- .robustsummary.lm(model.DDM, robust=FALSE)
-    return.object.1$call <- form2
+    return.object.1        <- .robustsummary.lm(model.DDM, robust=FALSE)
+    return.object.1$call   <- form2
     return(return.object.1)}
-  
-  
 }
\ No newline at end of file
