@@ -121,13 +121,25 @@
 #' 
 #' @examples 
 #' \dontrun{
-#' data(Gravity)
+#' data(Gravity_no_zeros)
 #' 
 #' Tetrads(y="flow", dist="distw", x=c("rta"), k="USA", ell="JPN", 
-#' multiway_vcov=TRUE, data=Gravity)
+#' multiway_vcov=TRUE, data=Gravity_no_zeros)
 #' 
 #' Tetrads(y="flow", dist="distw", x=c("rta", "comcur", "contig"), 
-#' k="USA", ell="JPN", multiway_vcov=FALSE, data=Gravity)
+#' k="USA", ell="JPN", multiway_vcov=FALSE, data=Gravity_no_zeros)
+#' }
+#' 
+#' \dontshow{
+#' # examples for CRAN checks:
+#' # executable in < 5 sec together with the examples above
+#' # not shown to users
+#' 
+#' data(Gravity_no_zeros)
+#' # choose exemplarily 10 biggest countries for check data
+#' countries_chosen <- names(sort(table(Gravity_no_zeros$iso_o), decreasing = TRUE)[1:10])
+#' grav_small <- Gravity_no_zeros[Gravity_no_zeros$iso_o %in% countries_chosen,]
+#' Tetrads(y="flow", dist="distw", x=c("rta"), k=countries_chosen[1], ell=countries_chosen[2], multiway_vcov=FALSE, data=grav_small)
 #' }
 #' 
 #' @return
@@ -137,59 +149,51 @@
 #' @seealso \code{\link[stats]{lm}}, \code{\link[lmtest]{coeftest}}, 
 #' \code{\link[multiwayvcov]{cluster.vcov}}
 #' 
-#' 
 #' @export 
 #' 
-Tetrads <- function(y, dist, x, k="USA", ell="JPN", multiway_vcov=TRUE, 
-                    data, ...){
-  if(!is.data.frame(data))stop("'data' must be a 'data.frame'")
-  if((multiway_vcov %in% c(TRUE, FALSE)) == FALSE){
-    stop("'multiway_vcov' has to be either 'TRUE' or 'FALSE'")}
+Tetrads <- function(y, dist, x, k="USA", ell="JPN", multiway_vcov=TRUE, data, ...){
+  
+  if(!is.data.frame(data))                                                stop("'data' must be a 'data.frame'")
   if(!is.character(y)     | !y%in%colnames(data)     | length(y)!=1)      stop("'y' must be a character of length 1 and a colname of 'data'")
   if(!is.character(dist)  | !dist%in%colnames(data)  | length(dist)!=1)   stop("'dist' must be a character of length 1 and a colname of 'data'")
-  if(!is.character(x)     | !all(x%in%colnames(data))) stop("'x' must be a character vector and all x's have to be colnames of 'data'")  
-  if(!k%in%data$iso_d) stop("'k' must be in 'data$iso_d'")
-  if(!ell%in%data$iso_o) stop("'ell' must be in 'data$iso_o'")
+  if(!is.character(x)     | !all(x%in%colnames(data)))                    stop("'x' must be a character vector and all x's have to be colnames of 'data'")  
+ 
+  if((multiway_vcov %in% c(TRUE, FALSE)) == FALSE)                        stop("'multiway_vcov' has to be either 'TRUE' or 'FALSE'")
+  if(!k%in%data$iso_d)                                                    stop("'k' must be in 'data$iso_d'")
+  if(!ell%in%data$iso_o)                                                  stop("'ell' must be in 'data$iso_o'")
+  
   # Transforming data, log flows and distances ---------------------------------
   
-  d <- data
-  d$dist_log <- (log(d[dist][,1]))
-  d$y_log <- log(d[y][,1])
+  d           <- data
+  d$dist_log  <- (log(d[dist][,1]))
+  d$y_log     <- log(d[y][,1])
   
   # Truncating dataset to only those countries which trade with reference
   # importer and exporter ------------------------------------------------------
   
-  d_2a <- d[d$iso_d == k,] # all iso_o which should stay in dataset
-  
-  d_2b <- d_2a$iso_o
-  
-  d_2 <- d[d$iso_o %in% d_2b,] 
-  
-  d_3a <- d_2[d_2$iso_o == ell,] # all iso_d which should stay in dataset
-  d_3b <- d_3a$iso_d
-  d_3 <- d_2[d_2$iso_d %in% d_3b,] 
-  
-  rm(data); rm(d); rm(d_2a);rm(d_2b); rm(d_2); rm(d_3a); rm(d_3b)
-  
+  d_2a        <- d[d$iso_d == k,] # all iso_o which should stay in dataset
+  d_2b        <- d_2a$iso_o
+  d_2         <- d[d$iso_o %in% d_2b,] 
+  d_3a        <- d_2[d_2$iso_o == ell,] # all iso_d which should stay in dataset
+  d_3b        <- d_3a$iso_d
+  d_3         <- d_2[d_2$iso_d %in% d_3b,] 
   num.ind.var <- length(x) #independent variables apart from distance
+  rm(data); rm(d); rm(d_2a);rm(d_2b); rm(d_2); rm(d_3a); rm(d_3b)
   
   # Taking ratios, ratk --------------------------------------------------------
   
-  d_3$lXinratk <- NA
+  d_3$lXinratk  <- NA
   d_3$ldistratk <- NA
   
   for(i in unique(d_3$iso_o)){
     
-    d_3[d_3$iso_o==i,]$lXinratk <- d_3[d_3$iso_o==i,]$y_log - 
-      d_3[d_3$iso_o==i & d_3$iso_d==k,]$y_log
-    
-    d_3[d_3$iso_o==i,]$ldistratk <- d_3[d_3$iso_o==i,]$dist_log - 
-      d_3[d_3$iso_o==i & d_3$iso_d==k,]$dist_log
+    d_3[d_3$iso_o==i,]$lXinratk <- d_3[d_3$iso_o==i,]$y_log - d_3[d_3$iso_o==i & d_3$iso_d==k,]$y_log
+    d_3[d_3$iso_o==i,]$ldistratk <- d_3[d_3$iso_o==i,]$dist_log - d_3[d_3$iso_o==i & d_3$iso_d==k,]$dist_log
   }
   
   # Taking ratios, ratk, for the other independent variables -------------------
   
-  ind.var.ratk <- list(length=num.ind.var+1)
+  ind.var.ratk                  <- list(length=num.ind.var+1)
   ind.var.ratk[[num.ind.var+1]] <- d_3$iso_o
   
   for(j in 1:num.ind.var){
@@ -198,10 +202,7 @@ Tetrads <- function(y, dist, x, k="USA", ell="JPN", multiway_vcov=TRUE,
   
   for(j in 1:num.ind.var){
     for(i in unique(d_3$iso_o)){
-      
-      ind.var.ratk[[j]][ind.var.ratk[[num.ind.var+1]]==i] <- 
-        ((d_3[d_3$iso_o==i,])[x[j]])[,1] - 
-        (d_3[d_3$iso_o==i & d_3$iso_d==k,])[x[j]][,1]
+      ind.var.ratk[[j]][ind.var.ratk[[num.ind.var+1]]==i] <- ((d_3[d_3$iso_o==i,])[x[j]])[,1] - (d_3[d_3$iso_o==i & d_3$iso_d==k,])[x[j]][,1]
     }
   }
   
@@ -211,25 +212,21 @@ Tetrads <- function(y, dist, x, k="USA", ell="JPN", multiway_vcov=TRUE,
   
   # Taking the ratio of ratios, rat --------------------------------------------
   
-  d_3$lXinrat <- NA
+  d_3$lXinrat  <- NA
   d_3$ldistrat <- NA
   
   for(i in unique(d_3$iso_d)){
     
-    d_3[d_3$iso_d==i,]$lXinrat <- d_3[d_3$iso_d==i,]$lXinratk - 
-      d_3[d_3$iso_d==i & d_3$iso_o==ell,]$lXinratk
-    
-    d_3[d_3$iso_d==i,]$ldistrat <- d_3[d_3$iso_d==i,]$ldistratk - 
-      d_3[d_3$iso_d==i & d_3$iso_o==ell,]$ldistratk
+    d_3[d_3$iso_d==i,]$lXinrat  <- d_3[d_3$iso_d==i,]$lXinratk - d_3[d_3$iso_d==i & d_3$iso_o==ell,]$lXinratk
+    d_3[d_3$iso_d==i,]$ldistrat <- d_3[d_3$iso_d==i,]$ldistratk - d_3[d_3$iso_d==i & d_3$iso_o==ell,]$ldistratk
   }
   
-  d_3$y_log_rat <- d_3$lXinrat
+  d_3$y_log_rat    <- d_3$lXinrat
   d_3$dist_log_rat <- d_3$ldistrat
   
   # Taking the ratio of ratios, rat, for the other independent variables -------
   
-  ind.var.rat <- list(length=num.ind.var+1)
-  
+  ind.var.rat                  <- list(length=num.ind.var+1)
   ind.var.rat[[num.ind.var+1]] <- d_3$iso_d
   
   for(j in 1:num.ind.var){
@@ -239,9 +236,7 @@ Tetrads <- function(y, dist, x, k="USA", ell="JPN", multiway_vcov=TRUE,
   for(j in 1:num.ind.var){
     for(i in unique(d_3$iso_d)){
       
-      ind.var.rat[[j]][ind.var.rat[[num.ind.var+1]]==i] <- 
-        ((d_3[d_3$iso_d==i,])[x[j]])[,1] - 
-        (d_3[d_3$iso_d==i & d_3$iso_o==ell,])[x[j]][,1]
+      ind.var.rat[[j]][ind.var.rat[[num.ind.var+1]]==i] <- ((d_3[d_3$iso_d==i,])[x[j]])[,1] - (d_3[d_3$iso_d==i & d_3$iso_o==ell,])[x[j]][,1]
     }
   }
   
@@ -255,39 +250,33 @@ Tetrads <- function(y, dist, x, k="USA", ell="JPN", multiway_vcov=TRUE,
   
   # new row in dataset for independent _rat variable
   for(j in x){
-    l <- which(x == j)
-    rat <- x_rat[l]
+    l        <- which(x == j)
+    rat      <- x_rat[l]
     d_3[rat] <- NA
     d_3[rat] <- d_3[x[l]]
   }
   
-  vars <- paste(c("dist_log_rat", x_rat), collapse=" + ")
-  form <- paste("y_log_rat","~",vars)
+  vars  <- paste(c("dist_log_rat", x_rat), collapse=" + ")
+  form  <- paste("y_log_rat","~",vars)
   form2 <- stats::as.formula(form)
-
-  model.Tetrads <- stats::lm(form2, data = d_3)
-
-  cluster.formula <- ~ iso_o + iso_d
-
-  model.Tetrads_vcov <- multiwayvcov::cluster.vcov(
-    model=model.Tetrads, cluster = cluster.formula)
-
-  model.Tetrads.robust <- lmtest::coeftest(
-    x=model.Tetrads, vcov=model.Tetrads_vcov)
+  
+  model.Tetrads        <- stats::lm(form2, data = d_3)
+  cluster.formula      <- ~ iso_o + iso_d
+  model.Tetrads_vcov   <- multiwayvcov::cluster.vcov(model=model.Tetrads, cluster = cluster.formula)
+  model.Tetrads.robust <- lmtest::coeftest(x=model.Tetrads, vcov=model.Tetrads_vcov)
   
   # Return ---------------------------------------------------------------------
   
   if(multiway_vcov == TRUE){
-    summary.Ted.1 <- .robustsummary.lm(model.Tetrads, robust=TRUE)
-    summary.Ted.1$coefficients <- 
-      model.Tetrads.robust[1:length(rownames(model.Tetrads.robust)),]
-    return.object.1 <- summary.Ted.1
-    return.object.1$call <- form2
+    summary.Ted.1              <- .robustsummary.lm(model.Tetrads, robust=TRUE)
+    summary.Ted.1$coefficients <- model.Tetrads.robust[1:length(rownames(model.Tetrads.robust)),]
+    return.object.1            <- summary.Ted.1
+    return.object.1$call       <- form2
     return(return.object.1)}
   
   if(multiway_vcov == FALSE){
-    return.object.1 <- .robustsummary.lm(model.Tetrads, robust=FALSE)
-    return.object.1$call <- form2
+    return.object.1            <- .robustsummary.lm(model.Tetrads, robust=FALSE)
+    return.object.1$call       <- form2
     return(return.object.1)}
-
+  
 }
\ No newline at end of file
